==> oci-2.44.1.tar.gz: oci-2.44.1/src/oci/core/models/update_compute_image_capability_schema_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateComputeImageCapabilitySchemaDetails(object):
    """
    Create Image Capability Schema for an image.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateComputeImageCapabilitySchemaDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateComputeImageCapabilitySchemaDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateComputeImageCapabilitySchemaDetails.
        :type freeform_tags: dict(str, str)

        :param schema_data:
            The value to assign to the schema_data property of this UpdateComputeImageCapabilitySchemaDetails.
        :type schema_data: dict(str, ImageCapabilitySchemaDescriptor)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateComputeImageCapabilitySchemaDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'schema_data': 'dict(str, ImageCapabilitySchemaDescriptor)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'schema_data': 'schemaData',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._freeform_tags = None
        self._schema_data = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateComputeImageCapabilitySchemaDetails.
        A user-friendly name for the compute image capability schema


        :return: The display_name of this UpdateComputeImageCapabilitySchemaDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateComputeImageCapabilitySchemaDetails.
        A user-friendly name for the compute image capability schema


        :param display_name: The display_name of this UpdateComputeImageCapabilitySchemaDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateComputeImageCapabilitySchemaDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateComputeImageCapabilitySchemaDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateComputeImageCapabilitySchemaDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateComputeImageCapabilitySchemaDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def schema_data(self):
        """
        Gets the schema_data of this UpdateComputeImageCapabilitySchemaDetails.
        The map of each capability name to its ImageCapabilitySchemaDescriptor.


        :return: The schema_data of this UpdateComputeImageCapabilitySchemaDetails.
        :rtype: dict(str, ImageCapabilitySchemaDescriptor)
        """
        return self._schema_data

    @schema_data.setter
    def schema_data(self, schema_data):
        """
        Sets the schema_data of this UpdateComputeImageCapabilitySchemaDetails.
        The map of each capability name to its ImageCapabilitySchemaDescriptor.


        :param schema_data: The schema_data of this UpdateComputeImageCapabilitySchemaDetails.
        :type: dict(str, ImageCapabilitySchemaDescriptor)
        """
        self._schema_data = schema_data

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateComputeImageCapabilitySchemaDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateComputeImageCapabilitySchemaDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateComputeImageCapabilitySchemaDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateComputeImageCapabilitySchemaDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.52.1.tar.gz: oci-2.52.1/src/oci/core/models/update_compute_image_capability_schema_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateComputeImageCapabilitySchemaDetails(object):
    """
    Create Image Capability Schema for an image.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateComputeImageCapabilitySchemaDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateComputeImageCapabilitySchemaDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateComputeImageCapabilitySchemaDetails.
        :type freeform_tags: dict(str, str)

        :param schema_data:
            The value to assign to the schema_data property of this UpdateComputeImageCapabilitySchemaDetails.
        :type schema_data: dict(str, ImageCapabilitySchemaDescriptor)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateComputeImageCapabilitySchemaDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'schema_data': 'dict(str, ImageCapabilitySchemaDescriptor)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'schema_data': 'schemaData',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._freeform_tags = None
        self._schema_data = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateComputeImageCapabilitySchemaDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdateComputeImageCapabilitySchemaDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateComputeImageCapabilitySchemaDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdateComputeImageCapabilitySchemaDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateComputeImageCapabilitySchemaDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateComputeImageCapabilitySchemaDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateComputeImageCapabilitySchemaDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateComputeImageCapabilitySchemaDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def schema_data(self):
        """
        Gets the schema_data of this UpdateComputeImageCapabilitySchemaDetails.
        The map of each capability name to its ImageCapabilitySchemaDescriptor.


        :return: The schema_data of this UpdateComputeImageCapabilitySchemaDetails.
        :rtype: dict(str, ImageCapabilitySchemaDescriptor)
        """
        return self._schema_data

    @schema_data.setter
    def schema_data(self, schema_data):
        """
        Sets the schema_data of this UpdateComputeImageCapabilitySchemaDetails.
        The map of each capability name to its ImageCapabilitySchemaDescriptor.


        :param schema_data: The schema_data of this UpdateComputeImageCapabilitySchemaDetails.
        :type: dict(str, ImageCapabilitySchemaDescriptor)
        """
        self._schema_data = schema_data

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateComputeImageCapabilitySchemaDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateComputeImageCapabilitySchemaDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateComputeImageCapabilitySchemaDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateComputeImageCapabilitySchemaDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
